==> impresscms_1.1.3_final.tar.gz: htdocs/class/xoopsform/formeditor.php <==
<?php
// $Id: formeditor.php,v 1.2 2007/10/03 11:58:47 marcan Exp $
//  ------------------------------------------------------------------------ //
//                XOOPS - PHP Content Management System                      //
//                    Copyright (c) 2000 XOOPS.org                           //
//                       <http://www.xoops.org/>                             //
//  ------------------------------------------------------------------------ //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
//  ------------------------------------------------------------------------ //
// Author: Kazumi Ono (AKA onokazu)                                          //
// URL: http://www.myweb.ne.jp/, http://www.xoops.org/, http://jp.xoops.org/ //
// Project: The XOOPS Project                                                //
// ------------------------------------------------------------------------- //
/**
 *
 *
 * @package     kernel
 * @subpackage  form
 *
 * @author	    Kazumi Ono	<onokazu@xoops.org>
 * @copyright	copyright (c) 2000-2003 XOOPS.org
 */

/**
 * XoopsEditor hanlder
 *
 * @author	D.J.
 * @copyright	copyright (c) 2000-2005 XOOPS.org
 *
 * @package     kernel
 * @subpackage  form
 */
class XoopsFormEditor extends XoopsFormTextArea
{
	var $editor;

	/**
	 * Constructor
	 *
   * @param	string  $caption    Caption
   * @param	string  $name       "name" attribute
   * @param	string  $value      Initial text
   * @param	array 	$configs     configures
   * @param	bool  	$noHtml       use non-WYSIWYG eitor onfailure
   * @param	string  $OnFailure editor to be used if current one failed
	 */
	function XoopsFormEditor($caption, $name, $editor_configs = null, $noHtml=false, $OnFailure = "")
	{
		$this->XoopsFormTextArea($caption, $editor_configs["name"]);
		require_once XOOPS_ROOT_PATH."/class/xoopseditor.php";
		$editor_handler = XoopsEditorHandler::getInstance();
		$this->editor =& $editor_handler->get($name, $editor_configs, $noHtml, $OnFailure);
	}



	/**
	 * Renders the editor
	 */
	function render()
	{
		return $this->editor->render();
	}
}
?>

==> impresscms_1.2.6_final.tar.gz: htdocs/class/xoopsform/formeditor.php <==
<?php
/**
* Creates a form editor object
*
* @copyright	http://www.xoops.org/ The XOOPS Project
* @copyright	XOOPS_copyrights.txt
* @copyright	http://www.impresscms.org/ The ImpressCMS Project
* @license	LICENSE.txt
* @package	XoopsForms
* @since	XOOPS
* @author	http://www.xoops.org The XOOPS Project
* @author	modified by UnderDog <underdog@impresscms.org>
* @version	$Id$
*/
/**
 *
 *
 * @package     kernel
 * @subpackage  form
 *
 * @author	    Kazumi Ono	<onokazu@xoops.org>
 * @copyright	copyright (c) 2000-2003 XOOPS.org
 */

/**
 * XoopsEditor hanlder
 *
 * @author	D.J.
 * @copyright	copyright (c) 2000-2005 XOOPS.org
 *
 * @package     kernel
 * @subpackage  form
 */
class XoopsFormEditor extends XoopsFormTextArea
{
	var $editor;

	/**
	 * Constructor
	 *
   * @param	string  $caption    Caption
   * @param	string  $name       "name" attribute
   * @param	string  $value      Initial text
   * @param	array 	$configs     configures
   * @param	bool  	$noHtml       use non-WYSIWYG eitor onfailure
   * @param	string  $OnFailure editor to be used if current one failed
	 */
	function XoopsFormEditor($caption, $name, $editor_configs = null, $noHtml=false, $OnFailure = "")
	{
		$this->XoopsFormTextArea($caption, $editor_configs["name"]);
		require_once ICMS_ROOT_PATH."/class/xoopseditor.php";
		$editor_handler = XoopsEditorHandler::getInstance();
		$this->editor =& $editor_handler->get($name, $editor_configs, $noHtml, $OnFailure);
	}



	/**
	 * Renders the editor
   * @return	string  the constructed html string for the editor
	 */
	function render()
	{
		return $this->editor->render();
	}
}

?>
